@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015 Canonical, Ltd.
+ * Copyright (C) 2015-2016 Canonical, Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License version 3, as published by
@@ -33,11 +33,15 @@ public:
     void setCursorName(const QString &cursorName) override;
     QString cursorName() const override;
 
+    QString currentKeymap() const override;
+    void setCurrentKeymap(const QString &currentKeymap) override;
+
 private:
     Mir();
     Q_DISABLE_COPY(Mir)
 
     QString m_cursorName;
+    QString m_currentKeymap;
     static qtmir::Mir *m_instance;
 };
 
