@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2015 Canonical, Ltd.
+ * Copyright (C) 2013-2017 Canonical, Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License version 3, as published by
@@ -21,25 +21,33 @@
 #include <QObject>
 #include <QWeakPointer>
 
+#include <memory>
+
+// qtmir
+namespace qtmir { class PromptSessionManager; }
+
 class QMirServerPrivate;
-class MirServer;
-class ScreenController;
+class ScreensController;
+class ScreensModel;
+class QPlatformOpenGLContext;
+class QOpenGLContext;
 
 class QMirServer: public QObject
 {
     Q_OBJECT
 
 public:
-    QMirServer(int &argc, char **argv, QObject* parent=0);
+    QMirServer(QObject *parent = nullptr);
     virtual ~QMirServer();
 
-    bool start();
+    void start();
     Q_SLOT void stop();
     bool isRunning() const;
 
-    QWeakPointer<MirServer> mirServer() const;
-
-    QWeakPointer<ScreenController> screenController() const;
+    QSharedPointer<ScreensModel> screensModel() const;
+    QPlatformOpenGLContext *createPlatformOpenGLContext(QOpenGLContext *context) const;
+    void *nativeResourceForIntegration(const QByteArray &resource) const;
+    std::shared_ptr<qtmir::PromptSessionManager> thePromptSessionManager() const;
 
 Q_SIGNALS:
     void started();
